aurora package
==============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   aurora.config
   aurora.pipelines
   aurora.sandbox
   aurora.test_utils
   aurora.time_series
   aurora.transfer_function

Submodules
----------

Module contents
---------------

.. automodule:: aurora
   :members:
   :undoc-members:
   :show-inheritance:
